#!perl
#
# RenderAllCameras.pl
# Mike King, Ethereal 3D
# Copyright (c) 2011 Ethereal 3D, All rights reserved.
# www.ethereal3d.com
# Render a scene with multiple cameras all out to disk from a single scene file.
#
# Saves all render outputs by prefixing any filenames with the CAMERANAME_
# to the same directory it was first set to save into
#

# Get number of cameras in the current scene
my $numberOfCameras = lxq( "query sceneservice camera.N ?" );
lxout( "# of cameras detected: $numberOfCameras" );

# Loop through and render each camera, changing output path
for ( $c=0; $c < $numberOfCameras; $c++) {
	# Get the item count
	my $n = lxq( "query sceneservice item.N ?" );

	# Loop through the items in the scene, looking for output items
	for( $i=0; $i < $n; $i++ ) {
		my $type = lxq( "query sceneservice item.type ? $i" );
		if( $type eq "renderOutput" ) {
			# Get the item ID
			$itemID = lxq( "query sceneservice item.id ? $i" );
			lxout( "Item ID:  $itemID" );

			# Select the item
			lx( "select.item $itemID" );

			# Get the original path
			my $originalPath = lxq( "item.channel renderOutput\$filename ?" );
			lxout("Original Path: $originalPath");
			# If the path is empty, skip it
			if( !$originalPath ) {
				next;
			}

			# Split the path from the filename using regex
			my @pathParts = split( /\/|\\/, $originalPath );
			if( @pathParts == 0 ) {
				# Nothing to split; path must consist of just the filename
				$filenamePart = $originalPath;
			} else {
				$filenamePart = $pathParts[ @pathParts - 1 ];
				#lxout("Filename: $filenamePart");
			}
			$basepath = @pathParts[0];
			for( $j=1; $j<@pathParts -1; $j++) {
				$part = @pathParts[$j];
				$basepath = "$basepath/$part";
			}
			#lxout("Basepath: $basepath");
			
			# Combine the passed in path with the original filename plus camera name.
			$cameraname = lxq( "query sceneservice camera.name ? $c" );
			$cameraitem = lxq( "query sceneservice camera.id ? $c" );
			
			lxout("*** Render camera: $cameraname ***");
			lxout("*** Render camera: $cameraitem ***");
			$newPath = ${basepath} . '/' . ${cameraname} . '_' . ${filenamePart};
			lxout("New Path: ${basepath}/${cameraname}_${filenamePart}");
			lx( "item.channel renderOutput\$filename {${basepath}/${cameraname}_${filenamePart}}" );
			lx( "render.camera ${cameraitem}");
			lx( "render.animation {*}" );
			# The scene is restored so the render outputs don't accidentally get saved with the camera in the path
			lx( "item.channel renderOutput\$filename {${originalPath}}");
		}
	}
}